@@ -11,7 +11,7 @@ def get_app() -> FastAPI:
 
 
 def main() -> None:
-    ServerLoggerConfigurator.setup_logger(settings)
+    ServerLoggerConfigurator.setup_logger()
     uvicorn.run(
         "superlinked.server.__main__:get_app",
         host=settings.SERVER_HOST,
