@@ -18,7 +18,8 @@ import sentry_sdk
 from asgi_correlation_id import CorrelationIdMiddleware
 from fastapi import FastAPI
 from fastapi.middleware.gzip import GZipMiddleware
-from opentelemetry.exporter.cloud_trace import CloudTraceSpanExporter
+from opentelemetry.exporter.otlp.proto.grpc.metric_exporter import OTLPMetricExporter
+from opentelemetry.exporter.otlp.proto.grpc.trace_exporter import OTLPSpanExporter
 from opentelemetry.sdk.metrics import MeterProvider
 from opentelemetry.sdk.metrics.export import PeriodicExportingMetricReader
 from opentelemetry.sdk.trace import TracerProvider
@@ -50,7 +51,6 @@ from superlinked.server.exception.exception_handler import (
 from superlinked.server.middleware.lifespan_event import lifespan
 from superlinked.server.middleware.timing_middleware import add_timing_middleware
 from superlinked.server.router.management_router import router as management_router
-from superlinked.server.util.retryable_cloud_exporter import RetryableCloudMonitoringMetricsExporter
 from superlinked.server.util.superlinked_app_downloader_util import download_from_gcs
 
 
@@ -109,15 +109,13 @@ class ServerApp:
         if not settings.OPENTELEMETRY_ENABLE:
             return
 
-        if not settings.OPENTELEMETRY_PROJECT_ID:
-            raise ValueError("OPENTELEMETRY_PROJECT_ID must be set in the environment variables")
+        if not settings.OPENTELEMETRY_HOST_URL:
+            raise ValueError("OPENTELEMETRY_HOST_URL must be defined when OPENTELEMETRY_ENABLE is true")
 
-        framework_version = VersionResolver.get_version_for_package("superlinked") or "unknown"
         server_version = VersionResolver.get_version_for_package("superlinked-server") or "unknown"
         labels = {
-            "service": settings.OPENTELEMETRY_COMPONENT_NAME,
-            "framework-version": framework_version,
-            "version": server_version,
+            "service.name": settings.OPENTELEMETRY_COMPONENT_NAME,
+            "service.version": server_version,
             "environment": settings.ENVIRONMENT_NAME,
         }
         telemetry.add_labels(labels)
@@ -135,21 +133,15 @@ class ServerApp:
             "item",
         )
 
-        metric_exporter = RetryableCloudMonitoringMetricsExporter(
-            settings.OPENTELEMETRY_PROJECT_ID,
-            add_unique_identifier=True,
-            max_attempts=settings.OPENTELEMETRY_RETRY_MAX_ATTEMPTS,
-        )
+        metric_exporter = OTLPMetricExporter(endpoint=settings.OPENTELEMETRY_HOST_URL, insecure=True)
+        metric_reader = PeriodicExportingMetricReader(exporter=metric_exporter)
 
-        metric_reader = PeriodicExportingMetricReader(
-            exporter=metric_exporter, export_interval_millis=settings.OPENTELEMETRY_EXPORT_INTERVAL_IN_MS
-        )
-
-        cloud_trace_exporter = CloudTraceSpanExporter(
-            project_id=settings.OPENTELEMETRY_PROJECT_ID,
+        trace_exporter = OTLPSpanExporter(
+            endpoint=settings.OPENTELEMETRY_HOST_URL,
+            insecure=True,
         )
         tracer_provider = TracerProvider(sampler=TraceIdRatioBased(settings.OPENTELEMETRY_TRACE_SAMPLING_RATE))
-        tracer_provider.add_span_processor(BatchSpanProcessor(cloud_trace_exporter))
+        tracer_provider.add_span_processor(BatchSpanProcessor(trace_exporter))
 
         telemetry.initialize(
             MeterProvider(metric_readers=[metric_reader]),
