@@ -56,11 +56,9 @@ class Settings(YamlBasedSettings):
 
     # OpenTelemetry
     OPENTELEMETRY_ENABLE: bool = False
+    OPENTELEMETRY_HOST_URL: str | None = None
     OPENTELEMETRY_COMPONENT_NAME: str = "superlinked-server"
-    OPENTELEMETRY_PROJECT_ID: str | None = None
-    OPENTELEMETRY_EXPORT_INTERVAL_IN_MS: int = 30000
-    OPENTELEMETRY_TRACE_SAMPLING_RATE: float = 1.0
-    OPENTELEMETRY_RETRY_MAX_ATTEMPTS: int = 5
+    OPENTELEMETRY_TRACE_SAMPLING_RATE: float = 0.1
 
     model_config = SettingsConfigDict(
         yaml_file=YAML_FILENAME, yaml_config_section=SERVER_SECTION, extra="ignore", frozen=True
