@@ -25,7 +25,7 @@ api_key_header = APIKeyHeader(name=API_KEY_NAME, auto_error=False)
 
 
 async def verify_api_key(api_key: str = Security(api_key_header)) -> None:
-    settings: Settings = Settings()
+    settings = Settings()
     api_key = api_key or ""  # compare_digest does not accept None
     if settings.API_KEY and not secrets.compare_digest(api_key, settings.API_KEY):
         raise HTTPException(
